@@ -71,4 +71,22 @@ config.bible_translation = bible_translation
 # general settings; stored on sever side
 config.bibles = dict(sorted({os.path.basename(i)[:-6]: i for i in glob.glob(os.path.join(BIBLEMATEGUI_DATA, "bibles", "*.bible"))}.items()))
 config.bibles_custom = dict(sorted({os.path.basename(i)[:-6]: i for i in glob.glob(os.path.join(BIBLEMATEGUI_DATA_CUSTOM, "bibles", "*.bible"))}.items()))
-config.available_tools = ["audio", "chronology"]
\ No newline at end of file
+config.available_tools = ["audio", "chronology"]
+
+# User Default Settings
+
+USER_DEFAULT_SETTINGS = {
+    'primary_color': '#2196F3', # A nice 'blue' hex code
+    'avatar': '',
+    'custom_token': '',
+    'default_bible': 'NET',
+    'default_commentary': 'CBSC',
+    'default_encyclopedia': 'ISBE',
+    'default_lexicon': 'Morphology',
+    'ai_backend': 'googleai',
+    'api_endpoint': '',
+    'api_key': '',
+    'language': 'English',
+    'dark_mode': False,
+    'fullscreen': False,
+}
\ No newline at end of file
