@@ -7,7 +7,7 @@ from biblemategui.js.sync_scrolling import *
 import re, os
 
 
-def original_reader(b=1, c=1, v=1, area=1, tab1=None, tab2=None, **_):
+def original_reader(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, **_):
 
     ui.on('luW', luW)
     ui.on('luV', luV)
@@ -118,7 +118,7 @@ def original_reader(b=1, c=1, v=1, area=1, tab1=None, tab2=None, **_):
     ui.add_head_html(ORIGINAL_CSS)
     
     # Bible Selection menu
-    bible_selector = BibleSelector(on_version_changed=change_area_1_bible_chapter if area == 1 else change_area_2_bible_chapter, on_book_changed=change_area_1_bible_chapter if area == 1 else change_area_2_bible_chapter, on_chapter_changed=change_area_1_bible_chapter if area == 1 else change_area_2_bible_chapter, on_verse_changed=change_bible_chapter_verse)
+    bible_selector = BibleSelector(on_version_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_book_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_chapter_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_verse_changed=change_bible_chapter_verse)
     bible_selector.create_ui("ORB", b, c, v)
 
     # Render the HTML inside a styled container
