@@ -571,7 +571,7 @@ class BibleMateGUI:
                             ui.menu_item('Tool Only', on_click=lambda: self.swap_layout(3))
                             ui.menu_item('Bible & Tool', on_click=lambda: self.swap_layout(2))
                             ui.separator()
-                            ui.menu_item('Preferences', on_click=lambda: self.load_area_2_content(self.work_in_progress))
+                            ui.menu_item('Preferences', on_click=lambda: ui.navigate.to('/settings'))
 
         # --- Drawer (Mobile Menu) ---
         # This section is unchanged
